"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const filter_by_pragma_1 = require("./filter-by-pragma");
const TestRunner = require("jest-runner");
class AllureTestRunner extends TestRunner {
    constructor(globalConfig, context) {
        super(globalConfig, context);
        const cliArgs = process.argv.slice(2);
        if (Array.isArray(cliArgs) && cliArgs.length > 0) {
            this._userArgs = this._extractArgs(cliArgs);
        }
    }
    async runTests(tests, watcher, onStart, onResult, onFailure, options) {
        let testsToRun = tests;
        if (this._userArgs && Object.keys(this._userArgs).length > 0) {
            console.info('Jest-DocBlock-runner: detected user arguments:', this._userArgs);
            const filteredTests = filter_by_pragma_1.filterByPragma(tests, this._userArgs);
            if (filteredTests.length > 0) {
                testsToRun = filteredTests;
                // TestsToRun.map(t => {
                // 	console.debug({t});
                // 	console.debug(`testNamePattern: ${t.context.config.testNamePattern}`);
                // });
            }
        }
        return super.runTests(testsToRun, watcher, onStart, onResult, onFailure, options);
    }
    _extractArgs(cliArgs) {
        const collectedArgs = {};
        for (const arg of cliArgs) {
            let [key, value] = arg.split('=', 2);
            if (!value || key === '-t') {
                continue;
            }
            if (key.includes('-')) {
                key = key.replace(/-/g, '');
            }
            collectedArgs[key] = value.split(',').map(s => s.trim());
        }
        return collectedArgs;
    }
}
exports.default = AllureTestRunner;
//# sourceMappingURL=runner.js.map